.. snek5000 documentation master file, created by
   sphinx-quickstart on Wed Dec 25 01:55:26 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to *snek5000*'s documentation!
===========================================

.. raw:: html


   <!--
      Icon derived from "wind slap icon" by Lorc. Available at
      https://game-icons.net/1x1/lorc/wind-slap.html .
      License: https://creativecommons.org/licenses/by/3.0/
   -->
   <img style="float: right;" src="_static/icon.svg" width="100rem"/>

+------------+-----------------------------------+
| Repository | https://github.com/exabl/snek5000 |
+------------+-----------------------------------+
| Version    | |release|                         |
+------------+-----------------------------------+

.. toctree::
   :maxdepth: 2
   :caption: Getting Started

   README

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   nek5000

.. autosummary::
   :toctree: _generated/

   snek5000

.. toctree::
   :maxdepth: 1
   :caption: Help & Reference

   roadmap
   boundary_cond
   filtering
   CONTRIBUTING
   CHANGELOG
   AUTHORS
   license

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

